@@ -3,6 +3,7 @@
 
 #include "paper.h"
 #include "graphicsstroke.h"
+#include "storage.h"
 
 class BasicUnitTests : public QObject
 {
@@ -18,4 +19,12 @@ private slots:
 
 };
 
+class StorageUnitTests : public QObject {
+    Q_OBJECT
+
+private slots:
+    void initTestCase();
+
+};
+
 #endif // BASICUNITTESTS_H
